/* reader.c - an example program to demonstrate suid access.
 * reader reads up to 5 lines of input from DB_FILE into an array,
 * and propmpts the user for a "record number", really a line number.
 * record number 0 means quit.
 * Written 2001 by Wayne Pollock, Tampa Florida USA.
 */

#include <stdio.h>

#define DB_FILE "secret.txt"
#define MAX_LINES (5)

int main ( void )
{
   FILE* fp;
   char lines[MAX_LINES][BUFSIZ];  /* An array of 0..MAX_LINES-1 strings. */
   char buf[BUFSIZ], junk[BUFSIZ];  /* string to hold user input */
   int c, i, line_num;

   /* Read the file into an array.  In a real DB we read the file each time. */
   fp = fopen( DB_FILE, "r" );
   if ( fp == NULL )
   {  fprintf( stderr, "\n\tAccess to \"secret.txt\" denied!\a\n" );
      return -1;
   }

   line_num = i = 0;
   while ( (c = getc(fp)) != EOF )
   {  if ( i >= (BUFSIZ - 2) )
         c = '\n';  /* end the line if too long */
      lines[line_num][i] = c;
      ++i;
      if ( c == '\n' )
      {  lines[line_num][i] = '\0';
         ++line_num;   i = 0;
         if ( line_num >= MAX_LINES )
            break;
      }
   }
   fclose( fp );

   /* Begin interactive part: */
   for ( ;; )
   {  fprintf( stderr, "\tEnter record number (1 - %i to display, 0 to quit): ",
               MAX_LINES );
      fgets( buf, BUFSIZ, stdin );
      if ( sscanf( buf, "%i%[^\r\n] ", &i, &junk ) != 1 )
      {  fprintf( stderr, "***Error:  Please enter a single number only!\a\n" );
         continue;
      }
      if ( i < 0 || i > MAX_LINES )
      {  fprintf( stderr, "***Error:  Enter a number between 0 and %i!\a\n",
                  MAX_LINES );
         continue;
      }
      if ( i == 0 )
         break;  /* all done! */
      fprintf(stderr, "\nRecord %i: %s\n", i, lines[i-1] );
   }
   return 0;
}
